@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Mock data creation
 
-our $VERSION = '0.1201';
+our $VERSION = '0.1300';
 
 use strict;
 use warnings;
@@ -82,7 +82,7 @@ sub date_modifier {
 sub time_ranger {
     my %args = @_;
     # Set defaults.
-    $args{stamp} ||= 1;
+    $args{stamp} //= 1;
     $args{start} ||= '00:00:00';
     $args{end}   ||= '';
     $args{N}     ||= NDATA;
@@ -385,7 +385,7 @@ Mock::Populate - Mock data creation
 
 =head1 VERSION
 
-version 0.1201
+version 0.1300
 
 =head1 SYNOPSIS
 
